Fixing Readme & File structure & Typos

Change-Id: I354b4e0e0448c3e8555d0b766b2c410c8049c2ff


[ROCm/rocprofiler commit: f308e36798]
This commit is contained in:
Ammar ELWazir
2023-05-31 15:41:49 +00:00
zatwierdzone przez Ammar Elwazir
rodzic a305118408
commit f033633c04
12 zmienionych plików z 170 dodań i 450 usunięć
@@ -42,16 +42,11 @@ __global__ void helloworld(char* in, char* out) {
int main(int argc, char* argv[]) {
hipDeviceProp_t devProp;
HIP_RC(hipGetDeviceProperties(&devProp, 0));
std::cout << " System minor " << devProp.minor << std::endl;
std::cout << " System major " << devProp.major << std::endl;
std::cout << " agent prop name " << devProp.name << std::endl;
/* Initial input,output for the host and create memory objects for the
* kernel*/
const char* input = "GdkknVnqkc";
size_t strlength = strlen(input);
std::cout << "input string:" << std::endl;
std::cout << input << std::endl;
char* output = reinterpret_cast<char*>(malloc(strlength + 1));
char* inputBuffer;
@@ -68,13 +63,7 @@ int main(int argc, char* argv[]) {
HIP_RC(hipFree(inputBuffer));
HIP_RC(hipFree(outputBuffer));
output[strlength] = '\0'; // Add the terminal character to the end of output.
std::cout << "\noutput string:" << std::endl;
std::cout << output << std::endl;
free(output);
std::cout << "Passed!\n";
return SUCCESS;
}
@@ -60,11 +60,6 @@ int main() {
hipDeviceProp_t devProp;
HIP_RC(hipGetDeviceProperties(&devProp, 0));
std::cout << " System minor " << devProp.minor << std::endl;
std::cout << " System major " << devProp.major << std::endl;
std::cout << " agent prop name " << devProp.name << std::endl;
std::cout << "hip Device prop succeeded " << std::endl;
int i;
int errors;
@@ -102,8 +97,6 @@ int main() {
}
if (errors != 0) {
printf("FAILED: %d errors\n", errors);
} else {
printf("PASSED!\n");
}
HIP_RC(hipFree(deviceA));
@@ -821,7 +821,6 @@ void __attribute__((constructor)) globalsetting() {
std::string app_path = GetRunningPath(running_path);
std::stringstream gfx_path;
gfx_path << app_path << metrics_path;
std::cout << gfx_path.str() << std::endl;
setenv("ROCPROFILER_METRICS_PATH", gfx_path.str().c_str(), true);
}